@@ -109,7 +109,7 @@ convenience method for quickly sharing axes.  It's simple doing:
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@cpan.org>
+Cory G Watson <gphat@cpan.org>
 
 =head1 SEE ALSO
 
